@@ -44,7 +44,7 @@ impl Web3 {
 
     pub async fn eth_accounts(&self) -> Result<Vec<Address>, Web3Error> {
         self.jsonrpc_client
-            .request_method("eth_accounts", Vec::<String>::new(), self.timeout, None)
+            .request_method("eth_accounts", Vec::<String>::new(), self.timeout)
             .await
     }
 
@@ -52,7 +52,7 @@ impl Web3 {
     pub async fn eth_chainid(&self) -> Result<Option<Uint256>, Web3Error> {
         let ret: Result<Uint256, Web3Error> = self
             .jsonrpc_client
-            .request_method("eth_chainId", Vec::<String>::new(), self.timeout, None)
+            .request_method("eth_chainId", Vec::<String>::new(), self.timeout)
             .await;
 
         Ok(Some(ret?))
@@ -61,14 +61,14 @@ impl Web3 {
     pub async fn net_version(&self) -> Result<u64, Web3Error> {
         let ret: Result<String, Web3Error> = self
             .jsonrpc_client
-            .request_method("net_version", Vec::<String>::new(), self.timeout, None)
+            .request_method("net_version", Vec::<String>::new(), self.timeout)
             .await;
         Ok(ret?.parse()?)
     }
 
     pub async fn eth_new_filter(&self, new_filter: NewFilter) -> Result<Uint256, Web3Error> {
         self.jsonrpc_client
-            .request_method("eth_newFilter", vec![new_filter], self.timeout, None)
+            .request_method("eth_newFilter", vec![new_filter], self.timeout)
             .await
     }
 
@@ -78,7 +78,6 @@ impl Web3 {
                 "eth_getFilterChanges",
                 vec![format!("{:#x}", filter_id.clone())],
                 self.timeout,
-                Some(10_000_000),
             )
             .await
     }
@@ -89,19 +88,13 @@ impl Web3 {
                 "eth_uninstallFilter",
                 vec![format!("{:#x}", filter_id.clone())],
                 self.timeout,
-                None,
             )
             .await
     }
 
     pub async fn eth_get_logs(&self, new_filter: NewFilter) -> Result<Vec<Log>, Web3Error> {
         self.jsonrpc_client
-            .request_method(
-                "eth_getLogs",
-                vec![new_filter],
-                self.timeout,
-                Some(10_000_000),
-            )
+            .request_method("eth_getLogs", vec![new_filter], self.timeout)
             .await
     }
 
@@ -111,7 +104,6 @@ impl Web3 {
                 "eth_getTransactionCount",
                 vec![address.to_string(), "latest".to_string()],
                 self.timeout,
-                None,
             )
             .await
     }
@@ -122,7 +114,7 @@ impl Web3 {
     pub async fn eth_gas_price(&self) -> Result<Uint256, Web3Error> {
         let median_gas = self
             .jsonrpc_client
-            .request_method("eth_gasPrice", Vec::<String>::new(), self.timeout, None)
+            .request_method("eth_gasPrice", Vec::<String>::new(), self.timeout)
             .await?;
         let base_gas = self.get_base_fee_per_gas().await?;
         Ok(match base_gas {
@@ -136,7 +128,7 @@ impl Web3 {
         transaction: TransactionRequest,
     ) -> Result<Uint256, Web3Error> {
         self.jsonrpc_client
-            .request_method("eth_estimateGas", vec![transaction], self.timeout, None)
+            .request_method("eth_estimateGas", vec![transaction], self.timeout)
             .await
     }
 
@@ -146,7 +138,6 @@ impl Web3 {
                 "eth_getBalance",
                 vec![address.to_string(), "latest".to_string()],
                 self.timeout,
-                None,
             )
             .await
     }
@@ -156,13 +147,13 @@ impl Web3 {
         transactions: Vec<TransactionRequest>,
     ) -> Result<Uint256, Web3Error> {
         self.jsonrpc_client
-            .request_method("eth_sendTransaction", transactions, self.timeout, None)
+            .request_method("eth_sendTransaction", transactions, self.timeout)
             .await
     }
 
     pub async fn eth_call(&self, transaction: TransactionRequest) -> Result<Data, Web3Error> {
         self.jsonrpc_client
-            .request_method("eth_call", (transaction, "latest"), self.timeout, None)
+            .request_method("eth_call", (transaction, "latest"), self.timeout)
             .await
     }
 
@@ -172,13 +163,13 @@ impl Web3 {
         block: Uint256,
     ) -> Result<Data, Web3Error> {
         self.jsonrpc_client
-            .request_method("eth_call", (transaction, block), self.timeout, None)
+            .request_method("eth_call", (transaction, block), self.timeout)
             .await
     }
 
     pub async fn eth_block_number(&self) -> Result<Uint256, Web3Error> {
         self.jsonrpc_client
-            .request_method("eth_blockNumber", Vec::<String>::new(), self.timeout, None)
+            .request_method("eth_blockNumber", Vec::<String>::new(), self.timeout)
             .await
     }
 
@@ -188,7 +179,6 @@ impl Web3 {
                 "eth_getBlockByNumber",
                 (format!("{:#x}", block_number), true),
                 self.timeout,
-                Some(10_000_000),
             )
             .await
     }
@@ -202,7 +192,6 @@ impl Web3 {
                 "eth_getBlockByNumber",
                 (format!("{:#x}", block_number), true),
                 self.timeout,
-                Some(10_000_000),
             )
             .await
     }
@@ -216,7 +205,6 @@ impl Web3 {
                 "eth_getBlockByNumber",
                 (format!("{:#x}", block_number), false),
                 self.timeout,
-                None,
             )
             .await
     }
@@ -230,52 +218,31 @@ impl Web3 {
                 "eth_getBlockByNumber",
                 (format!("{:#x}", block_number), false),
                 self.timeout,
-                None,
             )
             .await
     }
 
     pub async fn eth_get_latest_block(&self) -> Result<ConciseBlock, Web3Error> {
         self.jsonrpc_client
-            .request_method(
-                "eth_getBlockByNumber",
-                ("latest", false),
-                self.timeout,
-                None,
-            )
+            .request_method("eth_getBlockByNumber", ("latest", false), self.timeout)
             .await
     }
 
     pub async fn xdai_get_latest_block(&self) -> Result<ConciseXdaiBlock, Web3Error> {
         self.jsonrpc_client
-            .request_method(
-                "eth_getBlockByNumber",
-                ("latest", false),
-                self.timeout,
-                None,
-            )
+            .request_method("eth_getBlockByNumber", ("latest", false), self.timeout)
             .await
     }
 
     pub async fn eth_get_latest_block_full(&self) -> Result<Block, Web3Error> {
         self.jsonrpc_client
-            .request_method(
-                "eth_getBlockByNumber",
-                ("latest", true),
-                self.timeout,
-                Some(10_000_000),
-            )
+            .request_method("eth_getBlockByNumber", ("latest", true), self.timeout)
             .await
     }
 
     pub async fn xdai_get_latest_block_full(&self) -> Result<XdaiBlock, Web3Error> {
         self.jsonrpc_client
-            .request_method(
-                "eth_getBlockByNumber",
-                ("latest", true),
-                self.timeout,
-                Some(10_000_000),
-            )
+            .request_method("eth_getBlockByNumber", ("latest", true), self.timeout)
             .await
     }
 
@@ -285,7 +252,6 @@ impl Web3 {
                 "eth_sendRawTransaction",
                 vec![format!("0x{}", bytes_to_hex_str(&data))],
                 self.timeout,
-                None,
             )
             .await
     }
@@ -301,14 +267,13 @@ impl Web3 {
                 // returning it we'll keep it consistent.
                 vec![format!("{:#066x}", hash)],
                 self.timeout,
-                None,
             )
             .await
     }
 
     pub async fn evm_snapshot(&self) -> Result<Uint256, Web3Error> {
         self.jsonrpc_client
-            .request_method("evm_snapshot", Vec::<String>::new(), self.timeout, None)
+            .request_method("evm_snapshot", Vec::<String>::new(), self.timeout)
             .await
     }
 
@@ -318,7 +283,6 @@ impl Web3 {
                 "evm_revert",
                 vec![format!("{:#066x}", snapshot_id)],
                 self.timeout,
-                None,
             )
             .await
     }
@@ -709,6 +673,10 @@ fn test_block_response() {
         let val = web3.eth_get_latest_block().await;
         let val = val.expect("Actix failure");
         assert!(val.number > 10u32.into());
+
+        let val = web3.eth_get_latest_block_full().await;
+        let val = val.expect("Actix failure");
+        assert!(val.number > 10u32.into());
     });
 }
 
